#include <QApplication>
#include <QDebug>
#include <QFile>
#include <QFileInfo>
#include <QWebEngineUrlSchemeHandler>
#include <QWebEngineUrlRequestJob>
#include <QWebEngineProfile>
#include <QWebEngineView>

class SchemeHandler : public QWebEngineUrlSchemeHandler
{
    Q_OBJECT
public:
    SchemeHandler(QObject *parent = nullptr)
        : QWebEngineUrlSchemeHandler(parent)
    {}

    void requestStarted(QWebEngineUrlRequestJob *request) override
    {
        QFileInfo info(QStringLiteral("test.mp4"));
        Q_ASSERT(info.exists());
        qDebug() << "replying with mp4" << info.absoluteFilePath();
        request->reply(QByteArrayLiteral("video/mp4"), new QFile(info.absoluteFilePath(), request));

    }
};

int main(int argc, char **argv)
{
    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);

    QApplication app(argc, argv);

    QWebEngineProfile::defaultProfile()->installUrlSchemeHandler(QByteArrayLiteral("stream"), new SchemeHandler(&app));

    QWebEngineView view;
    view.show();
    QFileInfo info(QStringLiteral("test.html"));
    Q_ASSERT(info.exists());
    view.load(QUrl::fromLocalFile(info.absoluteFilePath()));

    return app.exec();
}

#include "main.moc"
